package com.xkrs.dao;

import com.xkrs.model.entity.PictureEntity;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Component;

import java.util.Optional;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/19 16:41
 */
@Component
public interface PictureDao extends JpaRepository<PictureEntity, Long>, JpaSpecificationExecutor<PictureEntity> {

    /**
     * 查询图片信息
     *
     * @param lotNo      批次号
     * @param machineNo  机器号
     * @param materialNo 物料号
     * @param modelNo    模具号
     * @param partNo     零件号
     * @return
     */
    @Query(value = "SELECT * FROM qc_inspection_picture WHERE lot_no = ? AND machine_no = ? AND material_no = ? AND model_no = ? AND part_no = ? ", nativeQuery = true)
    Optional<PictureEntity> selectPicture(String lotNo, String machineNo, String materialNo, String modelNo, String partNo);

    /**
     * 修改图片路径信息
     *
     * @param lotNo       批次号
     * @param machineNo   机器号
     * @param materialNo  物料号
     * @param modelNo     模具号
     * @param partNo      零件号
     * @param picturePath 图片路径
     */
    @Modifying(clearAutomatically = true)
    @Query(value = "UPDATE qc_inspection_picture SET picture_path = ?6 where lot_no = ?1 and machine_no = ?2 and material_no = ?3 and model_no = ?4 and part_no = ?5", nativeQuery = true)
    void updatePicturePath(String lotNo, String machineNo, String materialNo, String modelNo, String partNo, String picturePath);
}
